Learn R Programming

qclust (version 1.0)

dmm_fn: Component Densities of Gaussian Mixture Models with Associate Proportions

Description

Component densities of Gaussian mixture models multiplied by its associated proportion for each data points.

Usage

dmm_fn(x, means, vars, pis)

Arguments

x
A matrix of n by p. n is the sample size. p is the dimension.
means
Means of the Gaussian mixture model.
vars
Variances of the Gaussian mixture model.
pis
Proportions of the Gaussian mixture model.

Value

A matrix of n by m. n is the sample size. m is the complexity. Each column represents the data points' densities (multiplied by its associated proportion) for one component.